@@ -25,7 +25,7 @@ use Linux::Info::SysInfo::CPU::Arm;
 use Linux::Info::SysInfo::CPU::AMD;
 use Linux::Info::SysInfo::CPU::S390;
 
-our $VERSION = '2.18'; # VERSION
+our $VERSION = '2.19'; # VERSION
 
 my @_attribs = (
     'raw_time',   'hostname', 'domain', 'kernel',
@@ -241,8 +241,14 @@ sub _set_cpuinfo {
         my $data = <$fh>;
         close($fh);
 
-        confess
-"Failed to recognize the processor, submit the /proc/cpuinfo to this project as an issue.\n$data";
+        my @msg = (
+            'Failed to recognize the processor,',
+            'please submit the /proc/cpuinfo content below',
+            'to this project as an issue',
+            "\n$data\n",
+        );
+
+        confess join( ' ', @msg );
     }
 
     $self->{cpu} = "Linux::Info::SysInfo::CPU::$model"->new($filename);
@@ -252,15 +258,17 @@ sub _set_interfaces {
     my $self  = shift;
     my $class = ref($self);
     my $file  = $self->{files};
-    my @iface = ();
+    my @iface;
 
     my $filename = $file->{netdev};
     open my $fh, '<', $filename
       or confess "$class: unable to open $filename ($!)";
     { my $head = <$fh>; }
 
+    my $regex = qr/^\s*(\w+):/;
+
     while ( my $line = <$fh> ) {
-        if ( $line =~ /^\s*(\w+):/ ) {
+        if ( $line =~ $regex ) {
             push @iface, $1;
         }
     }
@@ -313,7 +321,7 @@ Linux::Info::SysInfo - Collect linux system information.
 
 =head1 VERSION
 
-version 2.18
+version 2.19
 
 =head1 SYNOPSIS
 
